@@ -398,19 +398,10 @@ lineServer <- function(id, data, data_label, data_varStruct = NULL, nfactor.limi
             linetype <- input$strata
           }
         }
-
-        if (is.null(input$pvalfont)) {
-          line.position.dodge <- 0
-          line.size <- 0.5
-          line.point.size <- 0.5
-          pval.font.size <- 4
-        } else {
-          line.position.dodge <- input$positiondodge
-          line.size <- input$size
-          line.point.size <- input$pointsize
-          pval.font.size <- input$pvalfont
-        }
-
+        line.position.dodge <- input$positiondodge
+        line.size <- input$size
+        line.point.size <- input$pointsize
+        pval.font.size <- input$pvalfont
 
         res.plot <- ggpubr::ggline(data, input$x_line, input$y_line,
           color = color, add = add, add.params = add.params, conf.int = input$lineci,
@@ -514,6 +505,9 @@ lineServer <- function(id, data, data_label, data_varStruct = NULL, nfactor.limi
         )
       })
 
+      # Dropdown button default
+      outputOptions(x = output, name = "option_kaplan", suspendWhenHidden = FALSE)
+
       return(lineInput)
     }
   )
